@@ -129,9 +129,15 @@ ODE_API void dSolveL1 (const dReal *L, dReal *b, int n, int nskip);
 ODE_API void dSolveL1T (const dReal *L, dReal *b, int n, int nskip);
 
 
-/* in matlab syntax: a(1:n) = a(1:n) .* d(1:n) */
+/* in matlab syntax: a(1:n) = a(1:n) .* d(1:n) 
+ */
 
-ODE_API void dVectorScale (dReal *a, const dReal *d, int n);
+ODE_API void dScaleVector (dReal *a, const dReal *d, int n);
+
+/* The function is an alias for @c dScaleVector.
+ * It has been deprecated because of a wrong naming schema used.
+ */
+ODE_API_DEPRECATED ODE_API void dVectorScale (dReal *a, const dReal *d, int n);
 
 
 /* given `L', a n*n lower triangular matrix with ones on the diagonal,
@@ -186,95 +192,9 @@ ODE_API void dLDLTRemove (dReal **A, const int *p, dReal *L, dReal *d,
  */
 ODE_API void dRemoveRowCol (dReal *A, int n, int nskip, int r);
 
-
-#if defined(__ODE__)
-
-void _dSetZero (dReal *a, size_t n);
-void _dSetValue (dReal *a, size_t n, dReal value);
-dReal _dDot (const dReal *a, const dReal *b, int n);
-void _dMultiply0 (dReal *A, const dReal *B, const dReal *C, int p,int q,int r);
-void _dMultiply1 (dReal *A, const dReal *B, const dReal *C, int p,int q,int r);
-void _dMultiply2 (dReal *A, const dReal *B, const dReal *C, int p,int q,int r);
-int _dFactorCholesky (dReal *A, int n, void *tmpbuf);
-void _dSolveCholesky (const dReal *L, dReal *b, int n, void *tmpbuf);
-int _dInvertPDMatrix (const dReal *A, dReal *Ainv, int n, void *tmpbuf);
-int _dIsPositiveDefinite (const dReal *A, int n, void *tmpbuf);
-void _dFactorLDLT (dReal *A, dReal *d, int n, int nskip);
-void _dSolveL1 (const dReal *L, dReal *b, int n, int nskip);
-void _dSolveL1T (const dReal *L, dReal *b, int n, int nskip);
-void _dVectorScale (dReal *a, const dReal *d, int n);
-void _dSolveLDLT (const dReal *L, const dReal *d, dReal *b, int n, int nskip);
-void _dLDLTAddTL (dReal *L, dReal *d, const dReal *a, int n, int nskip, void *tmpbuf);
-void _dLDLTRemove (dReal **A, const int *p, dReal *L, dReal *d, int n1, int n2, int r, int nskip, void *tmpbuf);
-void _dRemoveRowCol (dReal *A, int n, int nskip, int r);
-
-PURE_INLINE size_t _dEstimateFactorCholeskyTmpbufSize(int n)
-{
-  return dPAD(n) * sizeof(dReal);
-}
-
-PURE_INLINE size_t _dEstimateSolveCholeskyTmpbufSize(int n)
-{
-  return dPAD(n) * sizeof(dReal);
-}
-
-PURE_INLINE size_t _dEstimateInvertPDMatrixTmpbufSize(int n)
-{
-  size_t FactorCholesky_size = _dEstimateFactorCholeskyTmpbufSize(n);
-  size_t SolveCholesky_size = _dEstimateSolveCholeskyTmpbufSize(n);
-  size_t MaxCholesky_size = FactorCholesky_size > SolveCholesky_size ? FactorCholesky_size : SolveCholesky_size;
-  return dPAD(n) * (n + 1) * sizeof(dReal) + MaxCholesky_size;
-}
-
-PURE_INLINE size_t _dEstimateIsPositiveDefiniteTmpbufSize(int n)
-{
-  return dPAD(n) * n * sizeof(dReal) + _dEstimateFactorCholeskyTmpbufSize(n);
-}
-
-PURE_INLINE size_t _dEstimateLDLTAddTLTmpbufSize(int nskip)
-{
-  return nskip * 2 * sizeof(dReal);
-}
-
-PURE_INLINE size_t _dEstimateLDLTRemoveTmpbufSize(int n2, int nskip)
-{
-  return n2 * sizeof(dReal) + _dEstimateLDLTAddTLTmpbufSize(nskip);
-}
-
-// For internal use
-#define dSetZero(a, n) _dSetZero(a, n)
-#define dSetValue(a, n, value) _dSetValue(a, n, value)
-#define dDot(a, b, n) _dDot(a, b, n)
-#define dMultiply0(A, B, C, p, q, r) _dMultiply0(A, B, C, p, q, r)
-#define dMultiply1(A, B, C, p, q, r) _dMultiply1(A, B, C, p, q, r)
-#define dMultiply2(A, B, C, p, q, r) _dMultiply2(A, B, C, p, q, r)
-#define dFactorCholesky(A, n, tmpbuf) _dFactorCholesky(A, n, tmpbuf)
-#define dSolveCholesky(L, b, n, tmpbuf) _dSolveCholesky(L, b, n, tmpbuf)
-#define dInvertPDMatrix(A, Ainv, n, tmpbuf) _dInvertPDMatrix(A, Ainv, n, tmpbuf)
-#define dIsPositiveDefinite(A, n, tmpbuf) _dIsPositiveDefinite(A, n, tmpbuf)
-#define dFactorLDLT(A, d, n, nskip) _dFactorLDLT(A, d, n, nskip)
-#define dSolveL1(L, b, n, nskip) _dSolveL1(L, b, n, nskip)
-#define dSolveL1T(L, b, n, nskip) _dSolveL1T(L, b, n, nskip)
-#define dVectorScale(a, d, n) _dVectorScale(a, d, n)
-#define dSolveLDLT(L, d, b, n, nskip) _dSolveLDLT(L, d, b, n, nskip)
-#define dLDLTAddTL(L, d, a, n, nskip, tmpbuf) _dLDLTAddTL(L, d, a, n, nskip, tmpbuf)
-#define dLDLTRemove(A, p, L, d, n1, n2, r, nskip, tmpbuf) _dLDLTRemove(A, p, L, d, n1, n2, r, nskip, tmpbuf)
-#define dRemoveRowCol(A, n, nskip, r) _dRemoveRowCol(A, n, nskip, r)
-
-
-#define dEstimateFactorCholeskyTmpbufSize(n) _dEstimateFactorCholeskyTmpbufSize(n)
-#define dEstimateSolveCholeskyTmpbufSize(n) _dEstimateSolveCholeskyTmpbufSize(n)
-#define dEstimateInvertPDMatrixTmpbufSize(n) _dEstimateInvertPDMatrixTmpbufSize(n)
-#define dEstimateIsPositiveDefiniteTmpbufSize(n) _dEstimateIsPositiveDefiniteTmpbufSize(n)
-#define dEstimateLDLTAddTLTmpbufSize(nskip) _dEstimateLDLTAddTLTmpbufSize(nskip)
-#define dEstimateLDLTRemoveTmpbufSize(n2, nskip) _dEstimateLDLTRemoveTmpbufSize(n2, nskip)
-
-
-#endif // defined(__ODE__)
-
-
 #ifdef __cplusplus
 }
 #endif
 
+
 #endif
